# junit.html

Report generated on 20-Oct-2023 at 13:46:26 by pytest-html v4.0.2

## Environment

## Summary

28 tests took 00:00:02.

(Un)check the boxes to filter the results.

There are still tests running.
Reload this page to ge the latest results!
0 Failed, 28 Passed, 0 Skipped, 0 Expected failures, 0 Unexpected passes, 0 Errors, 0 Reruns
/

Result | Test | Duration | Links
--- | --- | --- | ---